All Classes and Interfaces

Class
Description
Access Log Handler.
Represent an static resource file.
Handler for static resources represented by the Asset contract.
An asset source is a collection or provider of Asset.
Represents a file attachment response.
Enumerates the configuration properties supported by Jooby.
Specific exception for bad request.
This class is a helper that provides a single entry point for bean validation without being strictly tied to a specific bean validation implementation.
Custom mapping of HTTP request to parameter.
HTTP body value.
Buffered output.
Default implementation of BufferedOutput.
An output factory backed by ByteBuffer.
Utility class to compute single byte range requests when response content length is known.
Class allowing the fine tune the browser cache behavior for assets.
Utility class that group one or more completion listeners and execute them in reverse order.
HTTP CONNECT verb for mvc routes.
Defines what media types a route can consume.
HTTP context allows you to interact with the HTTP Request and manipulate the HTTP Response.
Select an application base on context path prefix matching a provided path.
Allow access to context attributes from MVC route.
Instructs how a Value must be converted to the requested type.
Value converter for values that come from config, query, path, form, path parameters into more specific type.
Response cookie implementation.
Allow access to query parameter from MVC route method.
Cross-origin resource sharing.
Handle preflight and simple CORS requests.
Cross Site Request Forgery handler.
Like Context but with couple of default methods.
Default error handler with content negotiation support and optionally mute log statement base on status code or exception types.
HTTP DELETE verb for mvc routes.
Dispatch operator for MVC routes.
Application environment contains configuration object and active environment names.
Available environment options.
Catch and encode application errors.
Execution mode.
Simple extension contract for adding and reusing commons application infrastructure components and/or integrate with external libraries.
Represents a file download.
Allows creating a FileDownload with the specified FileDownload.Mode.
Add support for delete file on complete when created from FileDownload.build(Path, String) or FileDownload.build(Path).
Download mode.
File upload class, file upload are available when request body is encoded as MediaType.MULTIPART_FORMDATA.
Flash map.
Allow access to flash parameter from MVC route method.
Specific error for forbidden access.
Form class for direct MVC parameter provisioning.
Allow access to field or entire form from MVC route method.
Utility class that helps to wrap and delegate to another context.
Delegate/forwarding body.
Forwarding/Delegate pattern over Formdata.
Forwarding/Delegate pattern over QueryString.
Forwarding/Delegate pattern over Value.
Used internally to annotation generated MVC controllers.
HTTP GET verb for mvc routes.
Install a handler that at application shutdown time:
Server-agnostic abstraction for a native HTTP/2 gRPC exchange.
Core Service Provider Interface (SPI) for the gRPC extension.
HTTP HEAD verb for mvc routes.
Allow access to header value from MVC route method.
Add support for HTTP Head requests.
Representation of RFC7807 RFC9457 Problem schema.
Problem builder.
Represents an individual error within an HTTP Problem response.
Implementing HttpProblemMappable allows to control the transformation of exception into HttpProblem.
Represents an inline file response.
Generate by CSRF handler.
Welcome to Jooby!
Marks a class or its methods as a JSON-RPC 2.0 endpoint.
A pre-resolved decoder used at runtime to deserialize JSON-RPC parameter nodes into complex Java objects.
Standard JSON-RPC 2.0 Error Codes mapped to HTTP status codes.
Exception thrown when a JSON-RPC error occurs during routing, parsing, or execution.
Global Tier 1 Dispatcher for JSON-RPC 2.0 requests. *
The core JSON parsing SPI (Service Provider Interface) for JSON-RPC.
A stateful reader used at runtime to extract arguments from JSON-RPC parameters.
Represents a JSON-RPC 2.0 Request object, and simultaneously acts as an iterable container for batch requests.
Represents a JSON-RPC 2.0 Response object.
Represents the error object inside a JSON-RPC response.
Interface for generated JSON-RPC service glue code (*Rpc classes).
Describe the underlying logging system.
A ModelAndView which uses a map as model.
Implementation of media/content type.
Parse HTTP body into a target type.
Render a route output as a byte array.
Whether a HTTP method isn't supported.
Missing exception.
Used by template engines to renderer views.
Thrown by template engine when they are not capable of rendering a ModelAndView.
Whether the accept header isn't acceptable.
When a request doesn't match any of the available routes.
OpenAPI supports for Jooby.
Available formats.
Allows manually specifying MVC routes to be included in openapi documentation generation.
HTTP OPTIONS verb for mvc routes.
Output used to support multiple implementations like byte array, byte buffer, netty buffers.
Factory class for Output.
Configuration options for output buffers.
Allow access to a parameter from MVC route method and from multiple sources.
Fluent interface allowing to conveniently search context parameters in multiple sources.
Fluent interface allowing to conveniently search context parameters in multiple sources.
List of possible parameter sources supported by Context.lookup(String, ParamSource...).
HTTP PATCH verb for mvc routes.
Set a path for Mvc routes.
Allow access to path variable from MVC route method.
HTTP POST verb for mvc routes.
Global error handler that catches all exceptions, transforms them into RFC7807 compliant format and renders the response based on the `Accept` header value.
Defines what media types a route can produces.
Declarative JSON projection for route handlers.
A wrapper for a value and its associated Projection.
Hierarchical schema for JSON field selection.
Provisioning exception, throws by MVC routes when parameter binding fails.
HTTP PUT verb for mvc routes.
Allow access to query parameter from MVC route method.
Query string class for direct MVC parameter provisioning.
Rate limit handler using https://github.com/vladimir-bukhtoyarov/bucket4j.
Utility function for handling CompletionStage and Flow.Publisher.
Creates an object from Value.
Service locator pattern which may be provided by a dependency injection framework.
Thrown when a required service is not available.
Represents a generic type T.
Thread-Local request scope implementation useful for save/store request attribute and access to them using a static way.
Route contains information about the HTTP method, path pattern, which content types consumes and produces, etc..
Execute application logic after a response has been generated by a route handler.
Callback that allow to customize a route while the route pipeline is being created.
Decorates a handler and run logic before handler is executed.
Listener interface for events that are run at the completion of a request/response cycle (i.e.
Decorates a route handler by running logic before and after route handler.
Route handler here is where the application logic lives.
Route location.
Carry metadata for mvc/controller method.
Marker interface for reactive responses.
Give you access to all routes created inside a Router.path(String, Runnable).
Routing DSL functions.
Find route result.
Router options: ignoreCase: Indicates whenever routing algorithm does case-sensitive matching on an incoming request path.
The SameSite attribute of the Set-Cookie HTTP response header allows you to declare if your cookie should be restricted to a first-party or same-site context.
Non-blocking sender.
Write callback.
Web server contract.
Base class for server.
Available server options.
Server-Sent message emitter.
Server-Sent event handler.
Keep-alive task.
Server-Sent message.
Utility class to access application services.
Default registry that uses a simply key/value mechanism for storing and retrieving services.
Map binder, allow to partially register map entries.
List/Set binder, allow to partially register service and fetch them all as list/set.
HTTP session.
Allow access to session attributes from MVC route.
Load and save sessions from store (memory, database, etc.).
Base class for in-memory session store.
Find, save and delete a session token (cookie, header, parameter, etc) into/from the web Context.
Looks for a session ID from request cookie headers.
Looks for a session ID from request headers.
Looks for a session token from request cookie.
Collection of throwable interfaces to simplify exception handling on lambdas.
Throwable version of Consumer.
Two argument version of SneakyThrows.Consumer.
Three argument version of SneakyThrows.Consumer.
Four argument version of SneakyThrows.Consumer.
Five argument version of SneakyThrows.Consumer.
Six argument version of SneakyThrows.Consumer.
Seven argument version of SneakyThrows.Consumer.
Seven argument version of SneakyThrows.Consumer.
Throwable version of Function.
Throwable version of BiFunction.
Function with three arguments.
Function with four arguments.
Function with five arguments.
Function with six arguments.
Function with seven arguments.
Function with seven arguments.
Throwable version of SneakyThrows.Predicate.
Throwable version of SneakyThrows.Predicate.
Throwable version of Runnable.
Throwable version of Supplier.
Force SSL handler.
SSL options for enabling HTTPs in Jooby.
The desired SSL client authentication mode for SSL channels in server mode.
Allow to configure a custom SSLContext provider.
Collection of built-in/standard value converters.
Thrown when Jooby was unable to initialize and start an application up.
Controls the level of information logged during startup.
HTTP status codes.
Runtime exception with status code.
Template engine renderer.
HTTP TRACE verb for mvc routes.
The TRACE method performs a message loop-back test along the path to the target resource.
Useful together with the various route decorators like TransactionalRequest provided by extensions jooby-hibernate, jooby-jdbi or jooby-ebean to toggle it's effect for a single route.
Marks a controller class or a specific route method for tRPC TypeScript generation.
Marks a method as a tRPC mutation.
Marks a method as a tRPC query.
A pre-resolved decoder used at runtime to deserialize tRPC network payloads into complex Java objects.
Maps standard Jooby HTTP status codes to official tRPC error codes.
A specialized error handler that formats exceptions into tRPC-compliant JSON responses.
A specialized runtime exception that encapsulates a tRPC error.
Jooby extension that enables tRPC support for the application.
The core JSON parsing SPI (Service Provider Interface) for tRPC.
A stateful, sequential reader used at runtime to extract arguments from a tRPC network payload.
A standardized envelope for successful tRPC responses.
Type mismatch exception.
Specific error for unauthorized access.
Whether there is no decoder for the requested Content-Type.
Usage exceptions.
Wrap a context and run BeanValidator.validate(Context, Object) over HTTP request objects.
Result of bean validator.
Error message, common contract to render/serialize.
Error type, describe when it is a generic/global error or specific/field error.
Unified API for HTTP value.
Keep track of existing Converter and convert values to a more concrete type.
Websocket.
Web socket route handler.
Websocket initializer.
On close callback.
On connect callback.
On error callback.
On message callback.
Callback for sending messages.
Collection of websocket close status.
Websocket configurer.
Websocket message generated from a WebSocket.OnMessage callback.
Add common variables to as Context attributes so they are accessible from template engine.
Set of escaping routines for fixing cross-site scripting (XSS).