- Type Parameters:
V1- Input type.V2- Input type.V3- Input type.V4- Input type.V5- Input type.V6- Input type.
- Enclosing class:
SneakyThrows
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
Six argument version of
SneakyThrows.Consumer.
This class rethrow any exception using the SneakyThrows.propagate(Throwable) technique.
-
Method Summary
Modifier and TypeMethodDescriptiondefault voidPerforms this operation on the given arguments and throw any exception usingSneakyThrows.propagate(Throwable)method.voidPerforms this operation on the given arguments.
-
Method Details
-
tryAccept
Performs this operation on the given arguments.- Parameters:
v1- Argument.v2- Argument.v3- Argument.v4- Argument.v5- Argument.v6- Argument.- Throws:
Exception- If something goes wrong.
-
accept
Performs this operation on the given arguments and throw any exception usingSneakyThrows.propagate(Throwable)method.- Parameters:
v1- Argument.v2- Argument.v3- Argument.v4- Argument.v5- Argument.v6- Argument.
-