Serialized Form
-
Package io.jooby
-
Exception Class io.jooby.ModelAndView.UnsupportedModelAndView
class UnsupportedModelAndView extends IllegalArgumentException implements Serializable -
Exception Class io.jooby.Usage
class Usage extends RuntimeException implements Serializable
-
-
Package io.jooby.exception
-
Exception Class io.jooby.exception.BadRequestException
class BadRequestException extends StatusCodeException implements Serializable -
Exception Class io.jooby.exception.ForbiddenException
class ForbiddenException extends StatusCodeException implements Serializable -
Exception Class io.jooby.exception.InvalidCsrfToken
class InvalidCsrfToken extends ForbiddenException implements Serializable -
Exception Class io.jooby.exception.MethodNotAllowedException
class MethodNotAllowedException extends StatusCodeException implements Serializable -
Exception Class io.jooby.exception.MissingValueException
class MissingValueException extends BadRequestException implements Serializable-
Serialized Fields
-
name
String name
Parameter/field name.
-
-
-
Exception Class io.jooby.exception.NotAcceptableException
class NotAcceptableException extends StatusCodeException implements Serializable -
Exception Class io.jooby.exception.NotFoundException
class NotFoundException extends StatusCodeException implements Serializable -
Exception Class io.jooby.exception.ProvisioningException
class ProvisioningException extends BadRequestException implements Serializable -
Exception Class io.jooby.exception.RegistryException
class RegistryException extends StatusCodeException implements Serializable -
Exception Class io.jooby.exception.StartupException
class StartupException extends RuntimeException implements Serializable -
Exception Class io.jooby.exception.StatusCodeException
class StatusCodeException extends RuntimeException implements Serializable-
Serialized Fields
-
statusCode
StatusCode statusCode
The HTTP status code.
-
-
-
Exception Class io.jooby.exception.TypeMismatchException
class TypeMismatchException extends BadRequestException implements Serializable-
Serialized Fields
-
name
String name
Parameter/field name.
-
-
-
Exception Class io.jooby.exception.UnauthorizedException
class UnauthorizedException extends StatusCodeException implements Serializable -
Exception Class io.jooby.exception.UnsupportedMediaType
class UnsupportedMediaType extends StatusCodeException implements Serializable
-
-
Package io.jooby.problem
-
Exception Class io.jooby.problem.HttpProblem
class HttpProblem extends RuntimeException implements Serializable-
Serialized Fields
-
detail
String detail
A human-readable explanation of this problem. -
errors
List<HttpProblem.Error> errors
List of errors. -
headers
Map<String,
Object> headers Optional headers. -
instance
URI instance
An absolute URI that identifies this specific problem. -
parameters
Map<String,
Object> parameters Additional attributes of the problem. -
status
int status
The HTTP status code generated by the origin server for this occurrence of the problem. -
timestamp
String timestamp
A problem occurrence timestamp in ISO-8601 representation. -
title
String title
Human-readable summary of this problem. -
type
URI type
A URI reference that identifies the problem type. Consumers MUST use the "type" URI (after resolution, if necessary) as the problem type's primary identifier. When this member is not present, its value is assumed to be "about:blank". If the type URI is a locator (e.g., those with a "http" or "https" scheme), de-referencing it SHOULD provide human-readable documentation for the problem type (e.g., using HTML). However, consumers SHOULD NOT automatically dereference the type URI, unless they do so when providing information to developers (e.g., when a debugging tool is in use)
-
-
-
-
Package io.jooby.rpc.jsonrpc
-
Exception Class io.jooby.rpc.jsonrpc.JsonRpcException
class JsonRpcException extends RuntimeException implements Serializable-
Serialized Fields
-
code
JsonRpcErrorCode code
-
data
Object data
-
-
-
-
Package io.jooby.rpc.trpc
-
Exception Class io.jooby.rpc.trpc.TrpcException
class TrpcException extends RuntimeException implements Serializable-
Serialized Fields
-
errorCode
TrpcErrorCode errorCode
-
procedure
String procedure
-
-
-